Crate async_rt

Crate async_rt 

Re-exports

pub use crate::error::JoinError;
pub use crate::error::TimeoutError;
pub use crate::scoped::Scope;
pub use crate::scoped::ScopeExecutor;
pub use crate::scoped::ScopedJoinHandle;

Modules

arc
error
global
rc
rt
scoped
Structured concurrency scopes for async tasks.
task
tracker

Structs

AbortableJoinHandle
The same as JoinHandle but designed to abort the task when all associated references to the returned AbortableJoinHandle have been dropped.
CommunicationTask
A task that accepts messages
JoinHandle
An owned permission to join on a task (await its termination).
UnboundedCommunicationTask
A task that accepts messages

Traits

Executor
ExecutorBlockOn
ExecutorBlocking
ExecutorTimeout

Attribute Macros

main
Runs an async function as a synchronous entry point.
test
Runs an async function as a synchronous test.