#[non_exhaustive]pub enum JoinError {
Cancelled,
Aborted,
Panicked,
Empty,
Unknown,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Cancelled
The task was cancelled without an explicit abort request through its
JoinHandle, such as during runtime shutdown.
Aborted
The task was cancelled after JoinHandle::abort
was requested.
Panicked
The task panicked.
Empty
The task that was polled was empty or contained no pending future.
Unknown
Unknown error.