DefaultExecutor

Type Alias DefaultExecutor 

pub type DefaultExecutor = TokioExecutor;
Executor that selects an available runtime backend at compile time.

  • On non-Wasm targets with the tokio, smol, or compio feature enabled, it uses TokioExecutor, SmolExecutor, or CompioExecutor.
  • On non-Wasm targets with the threadpool feature enabled and the tokio, smol or compio feature disabled, it uses ThreadPoolExecutor.
  • On non-Wasm targets with only the lite runtime feature enabled, it uses LiteExecutor.
  • On Wasm targets, it uses WasmExecutor, backed by wasm-bindgen-futures.

Aliased Type

pub struct DefaultExecutor;