TokioRuntimeExecutor

Struct TokioRuntimeExecutor 

pub struct TokioRuntimeExecutor { /* private fields */ }
Tokio executor with an Runtime or Handle

Implementations

Source

impl TokioRuntimeExecutor

pub fn with_single_thread() -> Result<Self>

Creates a tokio runtime with the current thread scheduler selected.

pub fn with_multi_thread() -> Result<Self>

Creates a tokio runtime with multi-thread scheduler selected.

pub fn with_runtime(runtime: Runtime) -> Self

Create an executor with the supplied Runtime.

Note that the runtime remains alive until the final clone of this executor is dropped.

pub fn with_handle(handle: Handle) -> Self

Create an executor with the supplied Runtime.

Note that this executor does not own or keep the associated runtime alive. The runtime must remain running for spawned tasks to execute.

pub fn from_current_handle() -> Result<Self>

Create an executor from the existing Runtime

Note that this returns an error when called outside a Tokio runtime context. The resulting executor does not prevent that runtime from shutting down.