ScopeExecutor

Struct ScopeExecutor 

pub struct ScopeExecutor<'scope, E> { /* private fields */ }
An Executor wrapper that tracks spawned tasks so they can be canceled when a scope ends.

ScopeExecutor itself implements Executor, so it can be passed to any code that takes Executor every spawn performed through that code will be tracked by the scope.

Because submitted futures must still be Send + 'static (enforced by Executor::spawn), this flavour of scope does not allow borrowing from the enclosing stack frame. Use scope for that.