pub struct JoinHandle<T> { /* private fields */ }Expand description
An owned permission to join on a task (await its termination).
This can be seen as an equivalent to std::thread::JoinHandle but for Future tasks rather than a thread.
Note that the task associated with this JoinHandle will start running when
Executor::spawn is called according to the selected runtime, even if the
JoinHandle has not been awaited.
Dropping JoinHandle will not abort or cancel the task. In other words, the task will continue to run in the background
and any return value will be lost.
This struct is created by the Executor::spawn.
Implementations
Sourceimpl<T> JoinHandle<T>
impl<T> JoinHandle<T>
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Provide an empty JoinHandle with no associated task.
Sourceimpl<T> JoinHandle<T>
impl<T> JoinHandle<T>
Sourcepub fn abort(&self)
pub fn abort(&self)
Abort the task associated with the handle.
If cancellation is observed after this method is called, awaiting the
handle returns JoinError::Aborted. Cancellation without an abort
request through this handle returns JoinError::Cancelled.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Check if the task associated with this JoinHandle has finished.
Note that this method can return false even if JoinHandle::abort has been called on the
task due to the time it may take for the task to cancel.
Sourcepub fn replace(&mut self, handle: JoinHandle<T>)
pub fn replace(&mut self, handle: JoinHandle<T>)
Replace the current handle with the provided JoinHandle, while dropping the source.
Warning
Note that if this is called with a non-empty handle, the existing task
will not be terminated when it is replaced and could run indefinitely.
Best to use when JoinHandle is JoinHandle::empty where empty is a used
placeholder.
Sourcepub fn replace_in_place(&mut self, handle: &mut JoinHandle<T>)
pub fn replace_in_place(&mut self, handle: &mut JoinHandle<T>)
Replace the current handle with the provided JoinHandle, making the source become
an equivalent to JoinHandle::empty.
Warning
Note that if this is called with a non-empty handle, the existing task
will not be terminated when it is replaced and could run indefinitely.
Best to use when JoinHandle is JoinHandle::empty where empty is a used
placeholder, and you want to update the source later with another task handle.