block_on

Function block_on 

pub fn block_on<F: Future>(f: F) -> F::Output
Blocks the current thread until the provided future has completed.

Note that calling this function within an executor context may cause a deadlock.