spawn_abortable_timeout

Function spawn_abortable_timeout 

pub fn spawn_abortable_timeout<F>(
    duration: Duration,
    future: F,
) -> AbortableJoinHandle<Result<F::Output, TimeoutError>> 
where F: Future + Send + 'static, F::Output: Send + 'static,
Spawns a new asynchronous task, returning an abortable handle, that must complete within duration.

If it does not, the future is dropped and the task completes with TimeoutError.