pub fn spawn_coroutine_with_buffer<T, F, Fut>(
buffer: usize,
f: F,
) -> CommunicationTask<T>Expand description
Spawns a new asynchronous task that accepts messages to the task with a set buffer. This function returns a handle that allows sending a message, or if there is no reference to the handle at all (in other words, all handles are dropped), the task would be aborted.