pub fn spawn_unbounded_coroutine<T, F, Fut>(
f: F,
) -> UnboundedCommunicationTask<T>Expand description
Spawns a new asynchronous task that accepts unbounded messages to the task. This function returns a handle that allows sending a message, or if there is no reference to the handle at all (in other words, all handles are dropped), the task would be aborted.