TrackerExecutor

Struct TrackerExecutor 

pub struct TrackerExecutor<E> { /* private fields */ }
Track running tasks.

Note that there is no guarantee that the runtime would drop the future after it is done. Therefore, this should only be used for purely approx statistics and not actual numbers. Additionally, it does not track any tasks spawned directly by the runtime but only by Executor::spawn through this implementation against Executor.

Implementations

Source

impl<E: Executor> TrackerExecutor<E>

pub fn new(executor: E) -> Self

pub fn count(&self) -> usize

Number of active tasks.