Re-exports
pub use crate::error::JoinError;pub use crate::error::TimeoutError;pub use crate::scoped::Scope;pub use crate::scoped::ScopeExecutor;pub use crate::scoped::ScopedJoinHandle;
Modules
Structs
- Abortable
Join Handle - The same as
JoinHandlebut designed to abort the task when all associated references to the returnedAbortableJoinHandlehave been dropped. - Communication
Task - A task that accepts messages
- Join
Handle - An owned permission to join on a task (await its termination).
- Unbounded
Communication Task - A task that accepts messages