Run an async closure with a scoped Executor wrapper that
forwards spawns to this executor, waits for all spawned tasks
to finish when the closure returns, and aborts any outstanding
tasks if the scope future itself is cancelled.
Spawns a new asynchronous task that accepts messages to the task.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task that accepts messages to the task with a set buffer.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with provided context that accepts messages to the task with a set buffer.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with provided context that accepts messages to the task.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with a set channel buffer that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with provided context that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with a set channel buffer and provided context that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task that accepts unbounded messages to the task.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with provided context that accepts unbounded messages to the task.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.
Spawns a new asynchronous task with provided context that accepts messages to the task using channels.
This function returns a handle that allows sending a message, or if there is no reference to the handle at all
(in other words, all handles are dropped), the task would be aborted.