pub fn spawn_abortable_timeout<F>(
duration: Duration,
future: F,
) -> AbortableJoinHandle<Result<F::Output, TimeoutError>> ⓘExpand description
Spawns a new asynchronous task, returning an abortable handle, that must complete within
duration.
If it does not, the future is dropped and the task completes with TimeoutError.