pub fn spawn_coroutine_with_context<T, C, F, Fut>(
context: C,
f: F,
) -> CommunicationTask<T>Expand description
Spawns a new asynchronous task with provided context that accepts messages to the task. This function returns a handle that allows sending a message, or if there is no reference to the handle at all (in other words, all handles are dropped), the task would be aborted.
Note
If state must be borrowed across awaits,
use spawn_coroutine_with_receiver_and_context.